@@ -1,6 +1,6 @@
 import json
 from enum import Enum
-from .base import JobStep, Job, Upload
+from .base import JobStep, Job, Upload, Distribution
 
 
 class ZCFDStep(JobStep):
@@ -10,6 +10,10 @@ class ZCFDStep(JobStep):
     :vartype case_name: str
     :var problem_name: The name of the hdf5 mesh file
     :vartype problem_name: str
+    :var override_file: The name of the zcfd override file for overset meshes
+    :vartype override_file: str
+    :var cycles: How many cycles to run for
+    :vartype cycles: int
     :var restart: Is the case a restart from a previous solution
     :vartype restart: bool
     :var partitions: How many parallel partitions should the case use
@@ -20,6 +24,7 @@ class ZCFDStep(JobStep):
         self,
         case_name,
         problem_name,
+        override_file,
         cycles,
         restart=False,
         partitions=1,
@@ -29,6 +34,7 @@ class ZCFDStep(JobStep):
         self.step_name = "ZCFD"
         self.case_name = case_name
         self.problem_name = problem_name
+        self.override_file = override_file
         self.restart = restart
         self.partitions = partitions
         self.cycles = cycles
@@ -43,6 +49,18 @@ class ZCFDJob(Job):
     :type job_name: str
     :param data_path: The epic data path to the zCFD case directory
     :type data_path: str
+    :param case_name: The name of the python control file for the case
+    :type case_name: str
+    :param problem_name: The name of the hdf5 mesh file
+    :type problem_name: str
+    :param override_file: The name of the zcfd override file for overset meshes. Defaults to None.
+    :type override_file: str, optional
+    :param cycles: How many cycles to run for. Default 100.
+    :type cycles: int, optional
+    :param restart: Is the case a restart from a previous solution. Default False.
+    :type restart: bool, optional
+    :param partitions: How many parallel partitions should the case use. Default 1.
+    :type partitions: int, optional
 
     :var zcfd: zCFD JobStep object
     :vartype zcfd: :class:`ZCFDStep`
@@ -55,6 +73,7 @@ class ZCFDJob(Job):
         data_path,
         case_name,
         problem_name,
+        override_file=None,
         cycles=100,
         restart=False,
         partitions=1,
@@ -63,11 +82,13 @@ class ZCFDJob(Job):
         self.zcfd = ZCFDStep(
             case_name,
             problem_name,
+            override_file,
             cycles,
             restart=restart,
             partitions=partitions,
             execute_step=True,
         )
+        self.zcfd.task_distribution = Distribution.DEVICE
         self.add_step(self.zcfd)
 
     def get_applications_options(self):
@@ -81,6 +102,10 @@ class ZCFDJob(Job):
             "problem_name": self.zcfd.problem_name,
             "cycles": self.zcfd.cycles,
             "restart": self.zcfd.restart,
+            "override_file": self.zcfd.override_file,
+            "partitions": self.zcfd.partitions,
+            "solver_tasks_per_node": self.zcfd.task_distribution.value,
+            "solver_runtime": self.zcfd.runtime,
         }
 
     def get_job_create_spec(self, queue_code):
